@@ -959,7 +959,7 @@ def get_gcp_service_account(credentials, storage_client=None):
 
     """
     from google.oauth2.service_account import Credentials
-    from pyplatform-datalake import gcs_download_blob
+    from pyplatform.datalake import gcs_download_blob
     if isinstance(credentials, dict):
         credentials = Credentials.from_service_account_info(credentials)
         logging.debug(
